@@ -44,8 +44,8 @@ class VkontakteManager(models.Manager):
         '''
         try:
             assert self.model.slug_prefix and slug.startswith(self.model.slug_prefix)
-            remote_id = int(slug.replace(self.model.slug_prefix, ''))
-        except (AssertionError, ValueError):
+            remote_id = int(re.findall(r'^%s(\d+)$' % self.model.slug_prefix, slug)[0])
+        except (AssertionError, ValueError, IndexError):
             try:
                 return self.model.objects.get(screen_name=slug)
             except self.model.DoesNotExist:
@@ -104,10 +104,14 @@ class VkontakteManager(models.Manager):
         '''
         Retrieve objects from remote server
         '''
+        extra_fields = kwargs.pop('extra_fields', {})
+        extra_fields['fetched'] = datetime.now()
+
         response_list = self.api_call(*args, **kwargs)
 
-        if isinstance(response_list, dict):
-            response_list = [response_list]
+        return self.parse_response_list(response_list, extra_fields)
+
+    def parse_response_list(self, response_list, extra_fields=None):
 
         instances = []
         for resource in response_list:
@@ -128,6 +132,9 @@ class VkontakteManager(models.Manager):
                 raise e
 
             instance = self.model()
+            # important to do it before calling parse method
+            if extra_fields:
+                instance.__dict__.update(extra_fields)
             instance.parse(resource)
             instances += [instance]
 
@@ -139,9 +146,7 @@ class VkontakteManager(models.Manager):
         '''
         instances = []
         for instance in self.get(**kwargs):
-            instance.fetched = datetime.now()
             instances += [self.get_or_create_from_instance(instance)]
-
         return instances
 
 class VkontakteModel(models.Model):
